@@ -18,18 +18,22 @@
 check_key <- function(x, key = character(0), na_distinct = FALSE, x_name = NULL) {
   chk_data(x)
   chk_s3_class(key, "character")
+  if (!length(key)) {
+    return(invisible(x))
+  }
+
   chk_unique(key)
   chk_not_any_na(key)
   chk_flag(na_distinct)
 
   if (is.null(x_name)) x_name <- deparse_backtick_chk((substitute(x)))
   chk_string(x_name)
-  if (!length(key)) {
-    return(invisible(x))
-  } # to ensure not tripped up by sf objects.
 
   check_names(x, key, x_name = x_name)
 
+  # to ensure not tripped up by sf objects.
+  x <- as.data.frame(x)
+
   incomparables <- if (na_distinct) NA else FALSE
   if (any(new_duplicated(x[key], incomparables = incomparables))) {
     abort_chk("Column%s ", cc(key, conj = " and "), " in ", x_name, " must be a unique key.", n = length(key))
